# PyFrost
![PyFrost](https://github.com/Den4200/pyfrost/workflows/PyFrost/badge.svg?branch=master&event=push)
[![Documentation Status](https://readthedocs.org/projects/pyfrost/badge/?version=latest)](https://pyfrost.readthedocs.io/en/latest/?badge=latest)

An online chat library for creating the client and server.

## Installation
```cmd
pip install pyfrost
```

## Documentation
The documentation for this library can be found [here](https://pyfrost.readthedocs.io/).
